==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Reviews/language/lang-euskara.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/



define("_PREVIOUS","Aurreko orria");
define("_NEXT","Hurrengo orria");
define("_YOURNAME","Zure izena");
define("_SORTASC","Goruntz ordenatu");
define("_SORTDESC","Beruntz ordenatu");

define("_CANCEL","Kantzelatu");
define("_YES","Bai");
define("_NO","Ez");

define("_SCORE","Puntuazioa");

define("_REPLYMAIN","Komentarioa bidali");
define("_ALLOWEDHTML","HTML erabili daiteke:");
define("_POSTANON","Anonimo bidalketa");
define("_WRITEREVIEW","Berrikuspen bat idatzi");
define("_WRITEREVIEWFOR","Berrikuspen bat idatzi honetaz:");
define("_ENTERINFO","Informazioa mesedez, espezifikazioen barruan idatzi");
define("_PRODUCTTITLE","Produktoaren izena");
define("_NAMEPRODUCT","Errebisatutako Produktoaren izena.");
define("_REVIEW","Berrikuspena");
define("_CHECKREVIEW","Idatzi Berrikuspena. Zaindu zure idazkera. Gehienez 100 hitz. HTML etiketak erabil ditzakezu.");
define("_FULLNAMEREQ","Zure izen osoa (beharrezkoa)");
define("_REMAIL","Emaila");
define("_REMAILREQ","Zure Emaila. (beharrezkoa)");
define("_SELECTSCORE","Baloratu produkto hau");
define("_RELATEDLINK","Erlazionaturiko Lotora");
define("_PRODUCTSITE","Produktoaren Orrialde Ofiziala. Ziurtatu idatzitako URLa \"http://\"-kin hasten dela.");
define("_LINKTITLE","Loturaren Titulua");
define("_LINKTITLEREQ","Beharrezkoa erlazionaturiko Loturaren bat baldin baduzu, bestela ez..");
define("_RIMAGEFILE","Irudi Fitxategia");
define("_RIMAGEFILEREQ","Portadako irudiaren izena. Karpeta honetan dago: images/reviews/. (Ez da beharrezkoa)");
define("_CHECKINFO","Ziurtatu idatzitakoa zuzena dela, bai ortografiaz eta bai edukiz. Kontutan eduki ere, mayuskuletan idazteak garraxika hitzegitearen balio berdina daukala.");
define("_INVALIDTITLE","Titulu ez zuzena... ezin da zuriz egon");
define("_INVALIDSCORE","Puntuazio ez zuzena... 1 eta 10 bitartean izan behar da");
define("_INVALIDTEXT","Berrikuspenaren testua ez da zuzena... ezin da zuriz egon");
define("_INVALIDHITS","Hits-aren (irakurrienak) balio zenbaki oso bat izan behar du.");
define("_CHECKNAME","Idatzi zure Izena eta zure Emaila");
define("_INVALIDEMAIL","Emaila ez da zuzena (ad: zureizena@elgoibar.biz)");
define("_INVALIDLINK","Biak, Lotura eta Loturaren titulua idatzi behar dituzu, edo bestela zuriz utzi");
define("_ADDED","Gehitzekoa:");
define("_REVIEWER","moderatzaile :");
define("_REVIEWID","Berrikuspenaren ID-a (identifikatiboa)");
define("_HITS","Hits-ak (irakurrienak)");
define("_LOOKSRIGHT","Dena zuzen dago?");
define("_RMODIFIED","aldatua");
define("_RADDED","gehitua");

define("_ADMINLOGGED","Oraintxe bertan administratzaile bat dago sisteman... berrikuspen hau berehala ikusi dezake.");
define("_RTHANKS","Eskerrikasko Berrikuspen hau bidaltzegatik");
define("_MODIFICATION","aldaketa");
define("_ISAVAILABLE","Iadanik erabilgarria dago Berrikuspen datubasean.");
define("_EDITORWILLLOOK","Editoreek egiaztatuko dute zure bidalketa. Laister izango duzu publikaturik!");
define("_RBACK","Bueltatu Berrikuspen aurkibidera");
define("_RWELCOME","Ongi etorri Berrikuspen Atalera");
define("_10MOSTPOP","Gehien irakurri diren 10 berrikuspenak");
define("_10MOSTREC","Bidalitako azken 10 berrikuspenak");
define("_THEREARE","Guztira");
define("_REVIEWSINDB","berrikuspen daude");
define("_REVIEWS","Berrikuspenak");
define("_REVIEWSLETTER","Letra honetatik hasten diren Berrikuspenak:");
define("_NOREVIEWS","Ez dago Berrikuspenik letra honetatik hasten denik");
define("_TOTALREVIEWS","Guztira aurkitu diren Berrikuspenak:");
define("_RETURN2MAIN","Bueltatu Menu Nagusira");
define("_REVIEWCOMMENT","Berrikuspenari buruzko Komentarioak (iruzkinak):");
define("_YOURNICK","Zure ezizena:");
define("_RCREATEACCOUNT","Sisteman <b><a href=user.php>erregistratu</a></b>");
define("_YOURCOMMENT","Zure Komentarioa:");
define("_MYSCORE","Balorazioa (zenbakia):");

define("_REVIEWMOD","Berrikuspena aldatzen");
define("_RDATE","Data:");
define("_RTITLE","Titulua:");
define("_RTEXT","Testua:");
define("_REVEMAIL","Emaila:");
define("_RLINK","Lotura:");
define("_RLINKTITLE","Loturaren ttulua:");
define("_COVERIMAGE","Hasierako irudia:");
define("_PREMODS","Aldaketen aurrebista");
define("_PAGE","orrialde ");
define("_PAGEBREAK","Orrialde batetan baino gehiagotan zatitzeko, idatzi <b>&lt;!--pagebreak--&gt;</b> orrialde berri baten mozketa sartzeko");
define("_PREVIEW","Aurrebista");
define("_LANGUAGE","Hizkuntza");


?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Reviews/language/lang-euskara.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/



define("_PREVIOUS","Aurreko orria");
define("_NEXT","Hurrengo orria");
define("_YOURNAME","Zure izena");
define("_SORTASC","Goruntz ordenatu");
define("_SORTDESC","Beruntz ordenatu");

define("_CANCEL","Kantzelatu");
define("_YES","Bai");
define("_NO","Ez");

define("_SCORE","Puntuazioa");

define("_REPLYMAIN","Komentarioa bidali");
define("_ALLOWEDHTML","HTML erabili daiteke:");
define("_POSTANON","Anonimo bidalketa");
define("_WRITEREVIEW","Berrikuspen bat idatzi");
define("_WRITEREVIEWFOR","Berrikuspen bat idatzi honetaz:");
define("_ENTERINFO","Informazioa mesedez, espezifikazioen barruan idatzi");
define("_PRODUCTTITLE","Produktoaren izena");
define("_NAMEPRODUCT","Errebisatutako Produktoaren izena.");
define("_REVIEW","Berrikuspena");
define("_CHECKREVIEW","Idatzi Berrikuspena. Zaindu zure idazkera. Gehienez 100 hitz. HTML etiketak erabil ditzakezu.");
define("_FULLNAMEREQ","Zure izen osoa (beharrezkoa)");
define("_REMAIL","Emaila");
define("_REMAILREQ","Zure Emaila. (beharrezkoa)");
define("_SELECTSCORE","Baloratu produkto hau");
define("_RELATEDLINK","Erlazionaturiko Lotora");
define("_PRODUCTSITE","Produktoaren Orrialde Ofiziala. Ziurtatu idatzitako URLa \"http://\"-kin hasten dela.");
define("_LINKTITLE","Loturaren Titulua");
define("_LINKTITLEREQ","Beharrezkoa erlazionaturiko Loturaren bat baldin baduzu, bestela ez..");
define("_RIMAGEFILE","Irudi Fitxategia");
define("_RIMAGEFILEREQ","Portadako irudiaren izena. Karpeta honetan dago: images/reviews/. (Ez da beharrezkoa)");
define("_CHECKINFO","Ziurtatu idatzitakoa zuzena dela, bai ortografiaz eta bai edukiz. Kontutan eduki ere, mayuskuletan idazteak garraxika hitzegitearen balio berdina daukala.");
define("_INVALIDTITLE","Titulu ez zuzena... ezin da zuriz egon");
define("_INVALIDSCORE","Puntuazio ez zuzena... 1 eta 10 bitartean izan behar da");
define("_INVALIDTEXT","Berrikuspenaren testua ez da zuzena... ezin da zuriz egon");
define("_INVALIDHITS","Hits-aren (irakurrienak) balio zenbaki oso bat izan behar du.");
define("_CHECKNAME","Idatzi zure Izena eta zure Emaila");
define("_INVALIDEMAIL","Emaila ez da zuzena (ad: zureizena@elgoibar.biz)");
define("_INVALIDLINK","Biak, Lotura eta Loturaren titulua idatzi behar dituzu, edo bestela zuriz utzi");
define("_ADDED","Gehitzekoa:");
define("_REVIEWER","moderatzaile :");
define("_REVIEWID","Berrikuspenaren ID-a (identifikatiboa)");
define("_HITS","Hits-ak (irakurrienak)");
define("_LOOKSRIGHT","Dena zuzen dago?");
define("_RMODIFIED","aldatua");
define("_RADDED","gehitua");

define("_ADMINLOGGED","Oraintxe bertan administratzaile bat dago sisteman... berrikuspen hau berehala ikusi dezake.");
define("_RTHANKS","Eskerrikasko Berrikuspen hau bidaltzegatik");
define("_MODIFICATION","aldaketa");
define("_ISAVAILABLE","Iadanik erabilgarria dago Berrikuspen datubasean.");
define("_EDITORWILLLOOK","Editoreek egiaztatuko dute zure bidalketa. Laister izango duzu publikaturik!");
define("_RBACK","Bueltatu Berrikuspen aurkibidera");
define("_RWELCOME","Ongi etorri Berrikuspen Atalera");
define("_10MOSTPOP","Gehien irakurri diren 10 berrikuspenak");
define("_10MOSTREC","Bidalitako azken 10 berrikuspenak");
define("_THEREARE","Guztira");
define("_REVIEWSINDB","berrikuspen daude");
define("_REVIEWS","Berrikuspenak");
define("_REVIEWSLETTER","Letra honetatik hasten diren Berrikuspenak:");
define("_NOREVIEWS","Ez dago Berrikuspenik letra honetatik hasten denik");
define("_TOTALREVIEWS","Guztira aurkitu diren Berrikuspenak:");
define("_RETURN2MAIN","Bueltatu Menu Nagusira");
define("_REVIEWCOMMENT","Berrikuspenari buruzko Komentarioak (iruzkinak):");
define("_YOURNICK","Zure ezizena:");
define("_RCREATEACCOUNT","Sisteman <b><a href=user.php>erregistratu</a></b>");
define("_YOURCOMMENT","Zure Komentarioa:");
define("_MYSCORE","Balorazioa (zenbakia):");

define("_REVIEWMOD","Berrikuspena aldatzen");
define("_RDATE","Data:");
define("_RTITLE","Titulua:");
define("_RTEXT","Testua:");
define("_REVEMAIL","Emaila:");
define("_RLINK","Lotura:");
define("_RLINKTITLE","Loturaren ttulua:");
define("_COVERIMAGE","Hasierako irudia:");
define("_PREMODS","Aldaketen aurrebista");
define("_PAGE","orrialde ");
define("_PAGEBREAK","Orrialde batetan baino gehiagotan zatitzeko, idatzi <b>&lt;!--pagebreak--&gt;</b> orrialde berri baten mozketa sartzeko");
define("_PREVIEW","Aurrebista");
define("_LANGUAGE","Hizkuntza");


?>
